@@ -3,9 +3,9 @@
 ## author: Thomas Alexander Gerds
 ## created: Jun  6 2016 (09:02) 
 ## Version: 
-## last-updated: okt  8 2021 (15:53) 
-##           By: Brice Ozenne
-##     Update #: 399
+## last-updated: Mar  9 2022 (15:49) 
+##           By: Thomas Alexander Gerds
+##     Update #: 423
 #----------------------------------------------------------------------
 ## 
 ### Commentary:
@@ -122,6 +122,7 @@
 #' predictRisk(sfit,newdata=d[1:3,],times=c(1,3,5,10))
 #' 
 #' ## simulate learning and validation data
+#' set.seed(10)
 #' learndat <- sampleData(100,outcome="survival")
 #' valdat <- sampleData(100,outcome="survival")
 #' ## use the learning data to fit a Cox model
@@ -134,13 +135,14 @@
 #' ## This is a matrix with event probabilities (1-survival)
 #' ## one column for each of the 5 time points
 #' ## one row for each validation set individual
-#' 
+#'
+#' if (require("randomForestSRC",quietly=TRUE)){
 #' # Do the same for a randomSurvivalForest model
-#' # library(randomForestSRC)
-#' # rsfmodel <- rfsrc(Surv(time,event)~X1+X2,data=learndat)
-#' # prsfsurv=predictRisk(rsfmodel,newdata=valdat,times=seq(0,60,12))
-#' # plot(psurv,prsfsurv)
-#' 
+#' library(randomForestSRC)
+#' rsfmodel <- rfsrc(Surv(time,event)~X1+X2,data=learndat)
+#' prsfsurv=predictRisk(rsfmodel,newdata=valdat,times=seq(0,60,12))
+#' plot(psurv,prsfsurv)
+#' }
 #' ## Cox with ridge option
 #' f1 <- coxph(Surv(time,event)~X1+X2,data=learndat,x=TRUE,y=TRUE)
 #' f2 <- coxph(Surv(time,event)~ridge(X1)+ridge(X2),data=learndat,x=TRUE,y=TRUE)
@@ -312,8 +314,8 @@ predictRisk.glm <- function(object, newdata, iid = FALSE, average.iid = FALSE,..
         stop("Currently only the binomial family is implemented for predicting a status from a glm object.")
     }
 }
-## * predictRisk.multinomQ
-predictRisk.multinom <- function(object, newdata, iid = FALSE, average.iid = FALSE,...){
+## * predictRisk.multinom
+predictRisk.multinom <- function(object, newdata, iid = FALSE, average.iid = FALSE, cause = NULL, ...){
     n.obs <- NROW(newdata)
     n.class <- length(object$lev)
     n.coef <- length(coef(object))
@@ -328,6 +330,13 @@ predictRisk.multinom <- function(object, newdata, iid = FALSE, average.iid = FAL
     ## ** set correct level
     ## hidden argument: enable to ask for the prediction of a specific level
     level <- list(...)$level
+    if(!is.null(cause)){
+        if(is.null(level)){
+            level <- cause
+        }else if(!identical(cause,level)){
+            stop("Argument \'cause\' and argument \'level\' should take the same value. \n")
+        }
+    }
     if(!is.null(level)){
         if(length(level)>1){
             stop("Argument \'level\' must have length 1 \n")
@@ -437,7 +446,8 @@ predictRisk.multinom <- function(object, newdata, iid = FALSE, average.iid = FAL
             }
         }
     }
-
+    
+    ## ** export    
     return(out)
 }
 ## * predictRisk.formula
@@ -478,7 +488,7 @@ predictRisk.lrm <- function(object,newdata,...){
 ##' @rdname predictRisk
 ##' @method predictRisk rpart
 predictRisk.rpart <- function(object,newdata,...){
-    requireNamespace("rpart",quietly=FALSE)
+  requireNamespace("rpart",quietly=FALSE)
   p <- as.numeric(stats::predict(object,newdata=newdata))
   p
 }
@@ -1030,7 +1040,7 @@ predictRisk.CauseSpecificCox <- function (object, newdata, times, cause,
 ##' library(prodlim)
 ##' \dontrun{
 ##' ## too slow
-##' if (requireNamespace("penalized",quietly=TRUE)){
+##' if (require("penalized",quietly=TRUE)){
 ##' library(penalized)
 ##' set.seed(8)
 ##' d <- sampleData(200,outcome="binary")
