@@ -3,9 +3,9 @@
 ## Author: Thomas Alexander Gerds
 ## Created: Sep  2 2017 (08:01) 
 ## Version: 
-## Last-Updated: Dec  5 2020 (13:20) 
+## Last-Updated: Jan 12 2022 (09:04) 
 ##           By: Thomas Alexander Gerds
-##     Update #: 12
+##     Update #: 14
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -18,8 +18,8 @@ library(riskRegression)
 library(testthat)
 library(timereg)
 library(survival)
+
 test_that("start stop Cox: basehaz vs timereg",{
-    data(veteran)
     ## remove ties
     set.seed(17)
     veteran$jtime <- veteran$time+rnorm(NROW(veteran),mean=0,sd=0.001)
@@ -62,7 +62,8 @@ test_that("start stop CauseSpecificCox",{
     d <- rbindlist(list(d1,d2,d3))
     ## d[start>time,.(start,time,event)]
     fit <- CSC(list(Hist(time=time,event=event,entry=start)~X1+X4+log(X7)+X9),data=d)
-    expect_success(riskRegression:::predictRisk.CSCTD(fit,newdata=d[c(17:32),],landmark=2:5,times=1))
+    ## NOTE: expect_error with regexp=NA tests no error 
+    expect_error(riskRegression:::predictRisk.CSCTD(fit,newdata=d[c(17:32),],landmark=2:5,times=1), regexp = NA)
 })
 
 ######################################################################
